==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/a3/a397172cb4471c64b6bcc3e992efd6f8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/UserBundle/Config/services.php */
class __TwigTemplate_130d3e59fdcd7840ec7897776888ecc7 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

use Mautic\\CoreBundle\\DependencyInjection\\MauticCoreExtension;
use Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\ContainerConfigurator;

return function (ContainerConfigurator \$configurator): void {
    \$services = \$configurator->services()
        ->defaults()
        ->autowire()
        ->autoconfigure()
        ->public();

    \$excludes = [
    ];

    \$services->load('Mautic\\\\UserBundle\\\\', '../')
        ->exclude('../{'.implode(',', array_merge(MauticCoreExtension::DEFAULT_EXCLUDES, \$excludes)).'}');

    \$services->load('Mautic\\\\UserBundle\\\\Entity\\\\', '../Entity/*Repository.php')
        ->tag(Doctrine\\Bundle\\DoctrineBundle\\DependencyInjection\\Compiler\\ServiceRepositoryCompilerPass::REPOSITORY_SERVICE_TAG);

    \$services->alias(Mautic\\UserBundle\\Entity\\UserTokenRepositoryInterface::class, Mautic\\UserBundle\\Entity\\UserTokenRepository::class);

    \$services->alias('mautic.user.model.role', Mautic\\UserBundle\\Model\\RoleModel::class);
    \$services->alias('mautic.user.model.user', Mautic\\UserBundle\\Model\\UserModel::class);
    \$services->alias('mautic.user.repository.user_token', Mautic\\UserBundle\\Entity\\UserTokenRepository::class);
    \$services->alias('mautic.user.repository', Mautic\\UserBundle\\Entity\\UserRepository::class);
    \$services->alias('mautic.permission.repository', Mautic\\UserBundle\\Entity\\PermissionRepository::class);
    \$services->alias('mautic.user.model.password_strength_estimator', Mautic\\UserBundle\\Model\\PasswordStrengthEstimatorModel::class);
    \$services->get(Mautic\\UserBundle\\Form\\Validator\\Constraints\\NotWeakValidator::class)->tag('validator.constraint_validator');

    \$services->load('Mautic\\\\UserBundle\\\\Security\\\\SAML\\Store\\\\Request\\\\', '../Security/SAML/Store/Request/*.php');
    \$services->get(Mautic\\UserBundle\\Security\\SAML\\Store\\Request\\RequestStateStore::class)
        ->arg('\$prefix', '%lightsaml.store.request_session_prefix%')
        ->arg('\$suffix', '%lightsaml.store.request_session_sufix%');
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/UserBundle/Config/services.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/UserBundle/Config/services.php", "/var/www/mautic-ktn/app/bundles/UserBundle/Config/services.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/a3/a397172cb4471c64b6bcc3e992efd6f8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/UserBundle/Config/services.php */
class __TwigTemplate_130d3e59fdcd7840ec7897776888ecc7 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

use Mautic\\CoreBundle\\DependencyInjection\\MauticCoreExtension;
use Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\ContainerConfigurator;

return function (ContainerConfigurator \$configurator): void {
    \$services = \$configurator->services()
        ->defaults()
        ->autowire()
        ->autoconfigure()
        ->public();

    \$excludes = [
    ];

    \$services->load('Mautic\\\\UserBundle\\\\', '../')
        ->exclude('../{'.implode(',', array_merge(MauticCoreExtension::DEFAULT_EXCLUDES, \$excludes)).'}');

    \$services->load('Mautic\\\\UserBundle\\\\Entity\\\\', '../Entity/*Repository.php')
        ->tag(Doctrine\\Bundle\\DoctrineBundle\\DependencyInjection\\Compiler\\ServiceRepositoryCompilerPass::REPOSITORY_SERVICE_TAG);

    \$services->alias(Mautic\\UserBundle\\Entity\\UserTokenRepositoryInterface::class, Mautic\\UserBundle\\Entity\\UserTokenRepository::class);

    \$services->alias('mautic.user.model.role', Mautic\\UserBundle\\Model\\RoleModel::class);
    \$services->alias('mautic.user.model.user', Mautic\\UserBundle\\Model\\UserModel::class);
    \$services->alias('mautic.user.repository.user_token', Mautic\\UserBundle\\Entity\\UserTokenRepository::class);
    \$services->alias('mautic.user.repository', Mautic\\UserBundle\\Entity\\UserRepository::class);
    \$services->alias('mautic.permission.repository', Mautic\\UserBundle\\Entity\\PermissionRepository::class);
    \$services->alias('mautic.user.model.password_strength_estimator', Mautic\\UserBundle\\Model\\PasswordStrengthEstimatorModel::class);
    \$services->get(Mautic\\UserBundle\\Form\\Validator\\Constraints\\NotWeakValidator::class)->tag('validator.constraint_validator');

    \$services->load('Mautic\\\\UserBundle\\\\Security\\\\SAML\\Store\\\\Request\\\\', '../Security/SAML/Store/Request/*.php');
    \$services->get(Mautic\\UserBundle\\Security\\SAML\\Store\\Request\\RequestStateStore::class)
        ->arg('\$prefix', '%lightsaml.store.request_session_prefix%')
        ->arg('\$suffix', '%lightsaml.store.request_session_sufix%');
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/UserBundle/Config/services.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/UserBundle/Config/services.php", "/var/www/html/mauticGIT-Test/app/bundles/UserBundle/Config/services.php");
    }
}
